load_phf_player_box: Load fastRhockey PHF player box scores
Description
helper that loads multiple seasons from the data repo either into memory
or writes it into a db using some forwarded arguments in the dots
Usage
load_phf_player_box(
seasons = most_recent_phf_season(),
...,
dbConnection = NULL,
tablename = NULL
)
Arguments
- seasons
A vector of 4-digit years associated with given PHF seasons. (Min: 2011)
- ...
Additional arguments passed to an underlying function that writes
the season data into a database (used by update_phf_db()).
- dbConnection
A DBIConnection object, as returned by DBI::dbConnect()
- tablename
The name of the player box data table within the database
Examples
Run this code# \donttest{
try(load_phf_player_box(2021))
# }
Run the code above in your browser using DataLab