Learn R Programming

fastRhockey (version 0.4.0)

phf_team_box: PHF Team Boxscore

Description

phf_team_box: loads the team boxscore and shot/score data for a game into one data frame through just one function

Usage

phf_team_box(game_id)

Value

A dataframe of team-level box score information

Arguments

game_id

The unique ID code for the game that you are interested in viewing the data for

Examples

Run this code
# \donttest{
  try(phf_team_box(game_id = 420339))
# }

Run the code above in your browser using DataLab