Learn R Programming

fastRhockey (version 0.4.0)

load_phf_schedule: Load fastRhockey PHF schedules

Description

helper that loads multiple seasons from the data repo either into memory or writes it into a db using some forwarded arguments in the dots

Usage

load_phf_schedule(
  seasons = most_recent_phf_season(),
  ...,
  dbConnection = NULL,
  tablename = NULL
)

Value

Returns a tibble

Arguments

seasons

A vector of 4-digit years associated with given PHF seasons. (Min: 2011)

...

Additional arguments passed to an underlying function that writes the season data into a database (used by update_phf_db()).

dbConnection

A DBIConnection object, as returned by DBI::dbConnect()

tablename

The name of the schedule data table within the database

Examples

Run this code
# \donttest{
  try(load_phf_schedule(2021))
# }

Run the code above in your browser using DataLab