powered by
phf_team_box: loads the team boxscore and shot/score data for a game into one data frame through just one function
phf_team_box(game_id)
A dataframe of team-level box score information
The unique ID code for the game that you are interested in viewing the data for
# \donttest{ try(phf_team_box(game_id = 420339)) # }
Run the code above in your browser using DataLab